#
# bluetooth_send_files_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Ville Mäntysaari <ville.mantysaari@hiit.fi>
#          Pekka Kanerva <kanerva@hiit.fi>

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { "name": u"Send files via Bluetooth",
         "type": "python",
         "doc": u"Send multiple files to a one receipent via Bluetooth.",
         'parameters': [ (u'address', 'text', u''),
                         (u'channel', 'number', 9)],
         "tags": ['send files', 'bluetooth', 'phone'],
         "input": "list",
         "output": "anything"
    }

#---

from s4all.composer.runtime import ensure_list

def run(input, p):

    import socket, time, os

    address = p["address"]
    if len(address) == 0:
        address, services = socket.bt_obex_discover()
        channel = services['OBEX Object Push']
    else:
        try:
            address.index(":")
        except ValueError:
            if address[0] == "p" or address[0] == "P":
                # Tero's Nokia 6260
                address = '00:11:9F:6E:9A:51'
            elif address[0] == "s" or address[0] == "S":
                # Ville's Nokia 6600
                address = '00:60:57:D5:FF:F7'
            elif address[0] == "t" or address[0] == "T":
                # Tero's Nokia 6630
                address = '00:11:9F:CA:B1:E2'
            elif address[0] == "k" or address[0] == "K":
                # Ken's N70
                address = '00:17:4B:46:B8:19'
            elif address[0] == "v" or address[0] == "V":
                # Ville's N70
                address = '00:17:4B:46:B8:C7'
            elif address[0] == "b" or address[0] == "B":
                # Ville's Powerbook
                address = '00:11:24:68:60:B6'
            elif address[0] == "c" or address[0] == "C":
                # Ken's Powerbook
                address = '00:0D:93:03:29:F9'
            elif address[0] == "h" or address[0] == "H":
                address = '00:0A:3A:50:69:56'
            elif address[0] == "w" or  address[0] == "W":
                address = '00:11:24:68:60:B6'
            else:
                raise "named device unknown"
        channel = p["channel"]

    files_to_send = input

    if files_to_send is None or files_to_send == []:
        raise TypeError, "No input"

    for file in ensure_list(files_to_send):
        if not os.path.isfile(file):
            continue
        socket.bt_obex_send_file(address, channel, file)
        time.sleep(1)

    input[0] = u"Files sent"
    return input
