#
# find_contact_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Ville Mäntysaari <ville.mantysaari@hiit.fi>
#          Pekka Kanerva <kanerva@hiit.fi>

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { "name": u"Find a contact",
         "type": "python",
         "doc": u"Find a contact from phone's address book application",
         'parameters': [ (u'Input', 'combo', ([u'name', u'number'], 0)),
                         (u'pattern', 'text', u''),
                         (u'Returns', 'combo', ([u'name', u'number', u'email'], 1)) ],
         "tags": ['contact', 'find contact', 'number', 'phone'],
         'input': 'string',
         'output': 'string'
         }

#---

import appuifw, contacts

class ContactSearch:

    # XXX Maybe the search could be wrapped into a class...
    # Don't know really yet...

    def __init__(self, input, parameters):


        self.input = input
        
        self.parameters = parameters

        self.names_match = ['first_name', 'last_name',
                            'job_title',
                            'company_name', 'email_address']

        self.numbers_match = ['mobile_number', 'pager_number',
                              'phone_number', 'fax_number',
                              'video_number']


    def search(self):
        """
        Does the initial search from the Contacts DB according to the
        user's search pattern
        """
        contacts_db = contacts.open()
        self.matches = []
        search_pattern = self.parameters["pattern"]

        if search_pattern == u'':

            if(self.input == None):
                self.input = []
            
            if len(self.input) > 0:
                search_pattern = self.input[0]
            else:
                search_pattern = appuifw.query(u'Search for:', 'text')
        self.matches = contacts_db.find(search_pattern)
        
        return self.matches


    def filter_results(self):
        filter_rule = self.parameters["Returns"]

        filtered_list = []
        choose_list = []

        if filter_rule == u'name':

            choose_list = [ m.title for m in self.matches ]
            chosen = appuifw.popup_menu(choose_list, u'Choose person')
            return unicode(choose_list[chosen])


        elif filter_rule == u'number':

            name_list = [ m.title for m in self.matches ]
            number_list = [ m.find('mobile_number')[0].value
                            for m in self.matches if m.find('mobile_number')]
            
            chosen_person = appuifw.popup_menu(name_list, u'Choose person')
            number = number_list[chosen_person]
            print u'# number: %s' % number

            return unicode(number)

        elif filter_rule == u'email':

            name_list = [ m.title for m in self.matches ]
            email_list = [m.find('email_address')[0].value
                          for m in self.matches if m.find('email_address')]
            index = appuifw.popup_menu(name_list, u'Choose person')
            email = email_list[index]
            print u'# email: %s' % email

            return unicode(email)



def run(input, parameters):

    c = ContactSearch(input, parameters)
    matches = c.search()
    output = c.filter_results()
    input[0] = output
    return input
