#
# livedoor_weather_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Tero Hasu <tero.hasu@hut.fi>
#          

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { 'name': u'Livedoor Weather Service',
         "type": "python",
	 "paramtype": "tuples",
	 'doc':  u'Fetches a weather forecast (temperature only) for one of select Japanese cities.',
         'parameters': [(u'day', 'combo', ([u'today', u'tomorrow', u'day after tomorrow'], 1)),
                        (u'city', 'combo', ([u'Tokyo', u'Osaka', u'Nagoya', u'Sapporo', u'Fukuoka', u'Naha', u'Nagano', u'Niigata'], 0))],
         'tags': ['weather', 'web service'],
         'input': 'anything',
         'output': 'string'
       }	 

#---

import cElementTree as ET
import urllib

days = ["today",
        "tomorrow",
        "dayaftertomorrow"]

cities = [63, # Tokyo
          81, # Osaka
          38, # Nagoya
          4, # Sapporo
          31, # Fukuoka
          136, # Naha
          72, # Nagano
          50 # Niigata
          ]

def run(input, parameters):

    index = parameters[0][2][1]
    day = days[index]

    index = parameters[1][2][1]
    city = str(cities[index])

    res = urllib.urlopen("http://weather.livedoor.com/forecast/webservice/rest/v1?city=" + city + "&day=" + day)

    try:

        tree = ET.parse(res)
        min = tree.findtext('temperature/min/celsius')
        max = tree.findtext('temperature/max/celsius')

        result = 'City: ' + parameters[1][2][0][index] + ' Temperature (celsius): max ' + max +' '+ 'min ' + min + '.'

        input[0] = result
        
        return input

    finally:
        res.close()
