#
# loop_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Ville Mäntysaari <ville.mantysaari@hiit.fi>
#

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { "name": u"Loop",
         "type": "control",
         "doc": u"Run selected actions multiple times",
         'paramtype': 'tuples',
         'parameters': [ (u'Actions', 'number', 2),
                         (u'Repeats', 'number', 2) ],

         "tags": ['loop', 'repeat']
         }

#---

import sys
from s4all.composer.composer_workflow import ActionFailure
from s4all.composer.runtime import *

def run(wflow, input, parameters):

    loops = int(parameters[1][2])
    actions_to_loop = input[1]

    if actions_to_loop == [] or loops == '0':
        return

    temp = input[0] # Give same input all the time .. ?

    while(loops > 0):
        for entry in actions_to_loop:
            action = entry["action"]
            acttype = action["data"]["type"]
            if (acttype == "python" or acttype == "wsdl"):
                try:
                    params = wflow._current_config(entry)
                    argstype = action["data"].get("argstype", "dict")
                    if argstype == "dict":
                        params = wflow._config_list_to_map(params)
                        temp = action["module"].run(temp, params)
                except StopFlow, e:
                    raise # propagate up
                except Exception, e:
                    raise ActionFailure(action, sys.exc_info())
            elif acttype == "wflow":
                continue # Looping workflows to be done
        loops = loops - 1

    input = [temp, len(actions_to_loop)]

    return input # How many actions needed to skip after this action
                           # and the output the last action gave.
                    
        
        

    
