#
# next_matching_time_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Tero Hasu <tero.hasu@hut.fi>
#

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { 'name': u'Next matching time',
         "type": "python",
         'paramtype': 'tuples',
         'doc': u'Calculates the next date and time from the time of execution such that it matches the configuration parameters.',
	 'parameters': [ (u'weekday', 'combo', ([u'Monday', u'Tuesday', u'Wednesday', u'Thursday', u'Friday', u'Saturday', u'Sunday'], 0)),
                         (u'time', 'time', 0.0) ],
	 'tags': ['date', 'time', 'match', 'calculate'],
         'input': 'anything',
         'output': 'float'
	}

#---

import time

# Monday = 0, etc.
def get_weekday(datetime):
    ts = time.localtime(datetime)
    return ts[6]

def secs_in_day(datetime):
    ts = time.localtime(datetime)
    return (ts[3] * 60.0 + ts[4]) * 60.0 + ts[5]

def at_midnight(datetime):
    return datetime - secs_in_day(datetime)

def next_day(datetime):
    return datetime + (24 * 60 * 60)

# Given a weekday (0-6) and time of day (in seconds, as a float),
# calculates the next datetime from the present moment that matches
# the weekday and time of day.
def calculate_next(weekday, time_of_day):
    now = time.time()
    ntime = at_midnight(now) + time_of_day
    if now >= ntime:
        ntime = next_day(ntime)
    while get_weekday(ntime) != weekday:
        ntime = next_day(ntime)
    return ntime

def run(input, p):
    dow = p[0][2][1]
    tod = p[1][2]
    input[0] = calculate_next(dow, tod)
    return input
