#
# request_datetime_action.py
# 
# Copyright 2007 Helsinki Institute for Information Technology (HIIT)
# and the authors.  All rights reserved.
# 
# Authors: Tero Hasu <tero.hasu@hut.fi>
#

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
# 
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
# 
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
# NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
# BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
# ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
# CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

data = { 'name': u'Ask date and time',
         "type": "python",
         'doc': u'Request a date and a time from the user. The default value may be supplied as input. The flow is stopped if the user cancels either of the dialogs.',
	 'parameters': [ ('date label', 'text', u'date'),
                         ('time label', 'text', u'time') ],
	 'tags': ['date', 'time', 'ask', 'request', 'dialog'],
         'input': 'anything',
         'output': 'float'
	}

#---

import appuifw
import time
from s4all.composer.runtime import StopFlow

def run(input, p):
    default_time = input[0]
    if type(default_time) != float:
        default_time = time.time()

    ts = time.localtime(default_time)
    secs_in_day = (ts[3] * 60.0 + ts[4]) * 60.0 + ts[5]
    
    ddate = appuifw.query(p["date label"], 'date', default_time)
    if ddate is None:
        raise StopFlow, "no date given"
    
    dtime = appuifw.query(p["time label"], 'time', secs_in_day)
    if dtime is None:
        raise StopFlow, "no time given"

    input[0] = ddate + dtime
    return input
