# util.py
#
# Copyright 2006-2007 Helsinki Institute for Information Technology
# and the authors.
#
# Authors: Ville Mäntysaari <ville.mantysaari@hiit.fi>
#          Pekka Kanerva <kanerva@hiit.fi>
#	   Tero Hasu <tero.hasu@hut.fi>
#

# Permission is hereby granted, free of charge, to any person
# obtaining a copy of this software and associated documentation files
# (the "Software"), to deal in the Software without restriction,
# including without limitation the rights to use, copy, modify, merge,
# publish, distribute, sublicense, and/or sell copies of the Software,
# and to permit persons to whom the Software is furnished to do so,
# subject to the following conditions:
#
# The above copyright notice and this permission notice shall be
# included in all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
# MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
# IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY
# CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT,
# TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

import os
import sys
import appuifw

class Dialogs:
    def not_implemented():
        appuifw.note(u"Not implemented yet...", "error")
    not_implemented = staticmethod(not_implemented)

class Str:
    no_wflow = u"<no workflow open>"
    no_actions = u"<no actions>"
    empty = u"<empty>"

class Config:
    drive = sys.path[0][:2]
    actions_dir = drive + "\\System\\libs\\s4all\\actions\\"
    wsdl_dir = drive + "\\System\\libs\\s4all\\wsdl\\"

class Util:
    def action_files():
        return [ file for file
                 in os.listdir(Config.actions_dir)
                 if (not file.startswith("__") and
                     file.endswith(".py")) ]
    action_files = staticmethod(action_files)

    def wsdl_files():
        return [ file for file
                 in os.listdir(Config.wsdl_dir)
                 if (not file.startswith("__") and
                     file.endswith(".wsdl")) ]
    wsdl_files = staticmethod(wsdl_files)

    def wsdl_cache_file(wsdl_file):
        return wsdl_file[:-5] + ".cache.txt"
    wsdl_cache_file = staticmethod(wsdl_cache_file)

    def import_named(modname):
        """
        Imports the specified module, and returns it.
        Note that __import__ returns the top-level module.
        """
        # Returns the root module; must follow attrs to reach basename,
        # as instructed in __import__ API docs.
        mod = __import__(modname)
        for n in modname.split(".")[1:]:
            mod = getattr(mod, n)
        return mod
    import_named = staticmethod(import_named)

    def wflow_basename_from_name(name):
        return name + ".py"
    wflow_basename_from_name = staticmethod(wflow_basename_from_name)

    def file_exists(filename):
        try:
            f = open(filename, "r")
            f.close()
            return True
        except IOError:
            return False
    file_exists = staticmethod(file_exists)

    def wflow_exists_check(basename):
        if basename.startswith("workflow"):
            return True
        wflow_filename = Config.actions_dir + basename
        if Util.file_exists(wflow_filename):
            return appuifw.query(u"Workflow by that name already exists, proceed?", "query")
        return True
    wflow_exists_check = staticmethod(wflow_exists_check)
